==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/broker-core/src/main/java/org/apache/qpid/server/model/CommonAccessControlProvider.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.model;

import java.util.Comparator;

import org.apache.qpid.server.security.AccessControl;

public interface CommonAccessControlProvider<X> extends Comparable<X>
{
    String PRIORITY = "priority";

    Comparator<? super CommonAccessControlProvider> ACCESS_CONTROL_PROVIDER_COMPARATOR = new Comparator<CommonAccessControlProvider>()
    {
        @Override
        public int compare(final CommonAccessControlProvider o1, final CommonAccessControlProvider o2)
        {
            if(o1.getPriority() < o2.getPriority())
            {
                return -1;
            }
            else if (o1.getPriority() > o2.getPriority())
            {
                return 1;
            }
            else
            {
                return o1.getName().compareTo(o2.getName());
            }
        }
    };

    String getName();
    int getPriority();

    AccessControl<?> getController();
}

==> apache-qpid-broker-j-9.2.1-src.tar.gz: apache-qpid-broker-j-9.2.1-src/broker-core/src/main/java/org/apache/qpid/server/model/CommonAccessControlProvider.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.model;

import java.util.Comparator;

import org.apache.qpid.server.security.AccessControl;

public interface CommonAccessControlProvider<X> extends Comparable<X>
{
    String PRIORITY = "priority";

    Comparator<? super CommonAccessControlProvider> ACCESS_CONTROL_PROVIDER_COMPARATOR =
            (Comparator<CommonAccessControlProvider>) (o1, o2) ->
            {
                if(o1.getPriority() < o2.getPriority())
                {
                    return -1;
                }
                else if (o1.getPriority() > o2.getPriority())
                {
                    return 1;
                }
                else
                {
                    return o1.getName().compareTo(o2.getName());
                }
            };

    String getName();
    int getPriority();

    AccessControl<?> getController();
}
